@@ -7,6 +7,6 @@
 #define _INC_VERACRYPT_KEYFILE_H
 
 DECLSPEC u32 u8add (const u32 a, const u32 b);
-DECLSPEC u32 hc_apply_keyfile_vc (u32 *w, const int pw_len, const GLOBAL_AS vc_t *vc);
+DECLSPEC u32 hc_apply_keyfile_vc (PRIVATE_AS u32 *w, const int pw_len, const GLOBAL_AS vc_t *vc);
 
 #endif // _INC_VERACRYPT_KEYFILE_H
