@@ -6,6 +6,8 @@
 #include "common.h"
 #include "types.h"
 #include "interface.h"
+#include "memory.h"
+#include "shared.h"
 #include "benchmark.h"
 
 static const int DEFAULT_BENCHMARK_ALGORITHMS_BUF[] =
@@ -14,7 +16,7 @@ static const int DEFAULT_BENCHMARK_ALGORITHMS_BUF[] =
   100,
   1400,
   1700,
-  2500,
+  22000,
   1000,
   3000,
   5500,
@@ -40,7 +42,8 @@ static const int DEFAULT_BENCHMARK_ALGORITHMS_BUF[] =
 
 int benchmark_next (hashcat_ctx_t *hashcat_ctx)
 {
-  const user_options_t *user_options = hashcat_ctx->user_options;
+  const folder_config_t *folder_config = hashcat_ctx->folder_config;
+  const user_options_t  *user_options  = hashcat_ctx->user_options;
 
   static int cur = 0;
 
@@ -54,22 +57,26 @@ int benchmark_next (hashcat_ctx_t *hashcat_ctx)
 
     return hash_mode;
   }
-  else
+
+  char *modulefile = (char *) hcmalloc (HCBUFSIZ_TINY);
+
+  for (int i = cur; i < MODULE_HASH_MODES_MAXIMUM; i++)
   {
-    for (int i = cur; i < 99999; i++)
+    module_filename (folder_config, i, modulefile, HCBUFSIZ_TINY);
+
+    if (hc_path_exist (modulefile) == true)
     {
-      const char *name = strhashtype (i);
+      const int hash_mode = i;
 
-      if (name)
-      {
-        const int hash_mode = i;
+      cur = hash_mode + 1;
 
-        cur = hash_mode + 1;
+      hcfree (modulefile);
 
-        return hash_mode;
-      }
+      return hash_mode;
     }
   }
 
+  hcfree (modulefile);
+
   return -1;
 }
