@@ -47,6 +47,7 @@ static const char *const USAGE_BIG_PRE_HASHMODES[] =
   "     --markov-hcstat2           | File | Specify hcstat2 file to use                          | --markov-hcstat2=my.hcstat2",
   "     --markov-disable           |      | Disables markov-chains, emulates classic brute-force |",
   "     --markov-classic           |      | Enables classic markov-chains, no per-position       |",
+  "     --markov-inverse           |      | Enables inverse markov-chains, no per-position       |",
   " -t, --markov-threshold         | Num  | Threshold X when to stop accepting new markov-chains | -t 50",
   "     --runtime                  | Num  | Abort session after X seconds of runtime             | --runtime=10",
   "     --session                  | Str  | Define specific session name                         | --session=mysession",
@@ -56,7 +57,7 @@ static const char *const USAGE_BIG_PRE_HASHMODES[] =
   " -o, --outfile                  | File | Define outfile for recovered hash                    | -o outfile.txt",
   "     --outfile-format           | Str  | Outfile format to use, separated with commas         | --outfile-format=1,3",
   "     --outfile-autohex-disable  |      | Disable the use of $HEX[] in output plains           |",
-  "     --outfile-check-timer      | Num  | Sets seconds between outfile checks to X             | --outfile-check=30",
+  "     --outfile-check-timer      | Num  | Sets seconds between outfile checks to X             | --outfile-check-timer=30",
   "     --wordlist-autohex-disable |      | Disable the conversion of $HEX[] from the wordlist   |",
   " -p, --separator                | Char | Separator char for hashlists and outfile             | -p :",
   "     --stdout                   |      | Do not crack a hash, instead print candidates only   |",
@@ -93,8 +94,10 @@ static const char *const USAGE_BIG_PRE_HASHMODES[] =
   "     --hash-info                |      | Show information for each hash-mode                  |",
   "     --example-hashes           |      | Alias of --hash-info                                 |",
   "     --backend-ignore-cuda      |      | Do not try to open CUDA interface on startup         |",
+  "     --backend-ignore-hip       |      | Do not try to open HIP interface on startup          |",
+  "     --backend-ignore-metal     |      | Do not try to open Metal interface on startup        |",
   "     --backend-ignore-opencl    |      | Do not try to open OpenCL interface on startup       |",
-  " -I, --backend-info             |      | Show info about detected backend API devices         | -I",
+  " -I, --backend-info             |      | Show system/evironment/backend API info              | -I or -II",
   " -d, --backend-devices          | Str  | Backend devices to use, separated with commas        | -d 1",
   " -D, --opencl-device-types      | Str  | OpenCL device-types to use, separated with commas    | -D 1",
   " -O, --optimized-kernel-enable  |      | Enable optimized kernels (limits password length)    |",
@@ -142,8 +145,8 @@ static const char *const USAGE_BIG_PRE_HASHMODES[] =
   "",
   "- [ Hash modes ] -",
   "",
-  "      # | Name                                                | Category",
-  "  ======+=====================================================+======================================",
+  "      # | Name                                                       | Category",
+  "  ======+============================================================+======================================",
   NULL
 };
 
@@ -178,6 +181,7 @@ static const char *const USAGE_BIG_POST_HASHMODES[] =
   "  2 | Original-Word",
   "  3 | Original-Word:Finding-Rule",
   "  4 | Original-Word:Finding-Rule:Processed-Word",
+  "  5 | Original-Word:Finding-Rule:Processed-Word:Wordlist",
   "",
   "- [ Attack Modes ] -",
   "",
@@ -283,6 +287,13 @@ void usage_mini_print (const char *progname)
 
     fwrite (EOL, strlen (EOL), 1, stdout);
   }
+
+  #if defined (_WIN)
+  printf ("\n");
+  printf ("Press any key to exit\n");
+
+  getch ();
+  #endif
 }
 
 void usage_big_print (hashcat_ctx_t *hashcat_ctx)
@@ -334,7 +345,7 @@ void usage_big_print (hashcat_ctx_t *hashcat_ctx)
 
   for (int i = 0; i < usage_sort_cnt; i++)
   {
-    printf ("%7u | %-51s | %s", usage_sort_buf[i].hash_mode, usage_sort_buf[i].hash_name, strhashcategory (usage_sort_buf[i].hash_category));
+    printf ("%7u | %-58s | %s", usage_sort_buf[i].hash_mode, usage_sort_buf[i].hash_name, strhashcategory (usage_sort_buf[i].hash_category));
 
     fwrite (EOL, strlen (EOL), 1, stdout);
   }
